@@ -1,5 +1,5 @@
 package Net::Amazon::DynamoDB;
-$Net::Amazon::DynamoDB::VERSION = '0.002000';
+$Net::Amazon::DynamoDB::VERSION = '0.002001';
 
 use Moose;
 
@@ -1186,14 +1186,17 @@ sub scan_items {
             my $rvalue = ref( $val_ref ) || '';
             if ( $rvalue eq 'HASH' ) {
                 my ( $op, $value ) = %$val_ref;
+                my $value_list = (ref $value eq 'ARRAY')
+                    ? [ map { { $type => $_."" } } @$value ]
+                    : [ { $type => $value. '' } ];
                 $s_ref->{ $key } = {
-                    AttributeValueList => [ { $type => $value. '' } ],
+                    AttributeValueList => $value_list,
                     ComparisonOperator => uc( $op )
                 };
             }
             elsif( $rvalue eq 'ARRAY' ) {
                 $s_ref->{ $key } = {
-                    AttributeValueList => [ { $type => $val_ref } ],
+                    AttributeValueList => [ map { { $type => $_."" } } @$val_ref ],
                     ComparisonOperator => 'IN'
                 };
             }
@@ -1785,7 +1788,7 @@ Net::Amazon::DynamoDB
 
 =head1 VERSION
 
-version 0.002000
+version 0.002001
 
 =head1 SYNOPSIS
 
